type QueuedBlockList = Vec<QueuedBlock>;Expand description
A list of unverified blocks at a particular height.
Typically contains a single block, but might contain more if a peer has an old chain fork. (Or sends us a bad block.)
The CheckpointVerifier avoids creating zero-block lists.
Aliased Type
struct QueuedBlockList { /* private fields */ }Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 24 bytes